@@ -63,9 +63,17 @@ fn write_attachments(message: &Message) {
         match attachment {
             MessagePart::Text(text) | MessagePart::Html(text) => write_part(text),
             MessagePart::Binary(blob) | MessagePart::InlineBinary(blob) => write_part(blob),
-            MessagePart::Message(raw_message) => {
-                write_part(raw_message);
-                write_attachments(&raw_message.parse().unwrap());
+            MessagePart::Message(attached_message) => {
+                // Write attachments of nested messages
+                match &attached_message.body {
+                    MessageAttachment::Parsed(message) => write_attachments(message.as_ref()),
+                    MessageAttachment::Raw(_) => {
+                        write_attachments(&attached_message.parse_raw().unwrap())
+                    }
+                }
+
+                // Write raw message
+                write_part(attached_message);
             }
             _ => (),
         }
@@ -74,13 +82,7 @@ fn write_attachments(message: &Message) {
 
 fn write_part<'x>(part: &'x impl BodyPart<'x>) {
     std::fs::write(
-        part.get_content_disposition()
-            .and_then(|cd| cd.get_attribute("filename"))
-            .unwrap_or_else(|| {
-                part.get_content_type()
-                    .and_then(|ct| ct.get_attribute("name"))
-                    .unwrap_or("Untitled")
-            }),
+        part.get_attachment_name().unwrap_or("Untitled"),
         part.get_contents(),
     )
     .unwrap();
